/*
 * File:        appMenu.c
 * Description: Contains the user interface functionality for the UOC Car Share application
 * 				Basically, it implements the different menus that will be displayed on the screen
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "appMenu.h"
#include "operations.h"
#include "helpers.h"
#include "users.h"
#include "trips.h"


/* 
 * Function:    appMenu_mainMenu
 * Description: Displays the UOC Car Share main menu with the available operations
 * Arguments:   ---
 * Returns:     The option the user selected.
 */
char appMenu_mainMenu()
{
	int version;
	char option;
	
	helpers_clearScreen();
	
	version = ops_getVersion();
		
	printf("\nWelcome to the UOC Car Sharing application!\n");
	printf("\n-------------------------------------------\n\n");
	printf("Library version: %d\n\n", version);
	
	printf("Please, select a menu option:\n\n");
	printf("1. Login \n");
    printf("2. Register\n");
	printf("\n");
	printf("0. Exit\n\n");
	
	
	option = helpers_getOption();
	
	return option;
}


/* 
 * Function:    appMenu_userMenu
 * Description: Displays the User menu with the available operations
 * Arguments:   ---
 * Returns:     The option the user selected.
 */
char appMenu_userMenu(tUser * user)
{
	char option;
	
	helpers_clearScreen();
	
	if (user == NULL) 
	{
		return '0';
	}
	
	printf("\nHello, %s!\n", user->name);
	printf("\n-------------------------------------------\n\n");
	
	printf("Please, select a menu option:\n\n");
	printf("1. View my trips\n");
    printf("2. List all trips\n");
	printf("3. Publish new trip\n");
	printf("\n");
	printf("0. Logout\n\n");
	
	option = helpers_getOption();
	
	return option;
}

/* 
 * Function:    appMenu_register
 * Description: Requests the user to fill the necessary information to register
 * Arguments:   ---
 * Returns:     ---
 */
void appMenu_register()
{
	///
	/// EX.2.1: Request the information to register.
	///
	


	
	///
	/// END OF EX.2.1
	///
}

/* 
 * Function:    appMenu_login
 * Description: Validates the introduced credentials and matches them with the requesting user.
 * Arguments:   ---
 * Returns:     The user in the database that match with the introduced credentials. 
 *              It returns NULL in case there is no user that matches with that credentials.
 */
tUser * appMenu_login()
{
	tUser * retValue = NULL;
	
	///
	/// EX.2.2: Implement the login function
	///
	
    
	/// 
	/// END OF EX.2.2
	///
	
	return retValue;
}


/* 
 * Function:    appMenu_viewMyTrips
 * Description: Displays the list of trips a user has registered to. 
 * Arguments:   The user to filter.
 * Returns:     A character with the option introduced by the user.
 */
int appMenu_viewMyTrips(tUser * user)
{
	// NOTE: This function will be implemented on future exercices.
	
	helpers_clearScreen();
	
	printf("\nMy trips\n");
	printf("\n--------\n\n");
	
	printf("\nSelect a trip to display its information (0 to return to main menu)\n\n");
	
	helpers_pressAnyKey();
	
	return 0;
}

/* 
 * Function:    appMenu_listAllTrips
 * Description: Displays a list with all the registered trips in the database.
 * Arguments:   ---
 * Returns:     A character with the option introduced by the user
 */
int appMenu_listAllTrips()
{
	// NOTE: This function will be implemented on future exercices.
	
	helpers_clearScreen();
	
	printf("\nList of trips\n");
	printf("\n-------------\n\n");
	
	printf("\nSelect a trip to display its information (0 to return to main menu)\n\n");
	
	helpers_pressAnyKey();
	
	return 0;
}

/* 
 * Function:    appMenu_publishNewTrip
 * Description: Requests the user to fill the necessary information to publish a new trip.
 * Arguments:   ---
 * Returns:     The trip struct with all its information.
 */
tTrip * appMenu_publishNewTrip()
{
	tTrip * retValue = NULL;
	
	///
	/// EX.4.1: Obtain the information to publish a new trip.
	///
	



	///
	/// END OF EX.4.1
	///
	
	return retValue;
}

/* 
 * Function:    appMenu_displayTrip
 * Description: Displays the trip detailed information
 * Arguments:   The trip to display its information
 * Returns:     ---
 */
void appMenu_displayTrip(tTrip * trip)
{
	if (trip == NULL)
	{
		return;
	}
	
	helpers_clearScreen();
	
	printf("\nTrip information:\n");
	printf("\n-----------------\n\n");
	
	///
	/// EX.4.2.: Implement the instructions to display the trip detailed information
	///



    ///
	/// END OF EX.4.2
	///
	
	helpers_pressAnyKey();
}